@@ -11,9 +11,9 @@
 
 
 # Standard library imports.
-import builtins
+import six.moves.builtins
 from code import compile_command, InteractiveInterpreter
-from io import StringIO
+from six.moves import cStringIO as StringIO
 import sys
 from time import time
 
@@ -32,6 +32,7 @@ from .console.api import BracketMatcher, CallTipWidget, CompletionLexer, \
 from pyface.i_python_shell import IPythonShell, MPythonShell
 from pyface.key_pressed_event import KeyPressedEvent
 from .widget import Widget
+import six
 
 
 @provides(IPythonShell)
@@ -134,7 +135,7 @@ class PythonShell(MPythonShell, Widget):
         name = 'dragged'
 
         if hasattr(obj, 'name') \
-           and isinstance(obj.name, str) and len(obj.name) > 0:
+           and isinstance(obj.name, six.string_types) and len(obj.name) > 0:
             py_name = python_name(obj.name)
 
             # Make sure that the name is actually a valid Python identifier.
@@ -407,7 +408,7 @@ class PythonWidget(HistoryConsoleWidget):
                 leftover = leftover[0]
                 if symbol is None:
                     names = list(self.interpreter.locals.keys())
-                    names += list(builtins.__dict__.keys())
+                    names += list(six.moves.builtins.__dict__.keys())
                 else:
                     names = dir(symbol)
                 completions = [ n for n in names if n.startswith(leftover) ]
@@ -439,14 +440,14 @@ class PythonWidget(HistoryConsoleWidget):
         """ Find a python object in the interpeter namespace from a context (a
             list of names).
         """
-        context = list(map(str, context))
+        context = map(str, context)
         if len(context) == 0:
             return None, context
 
         base_symbol_string = context[0]
         symbol = self.interpreter.locals.get(base_symbol_string, None)
         if symbol is None:
-            symbol = builtins.__dict__.get(base_symbol_string, None)
+            symbol = six.moves.builtins.__dict__.get(base_symbol_string, None)
         if symbol is None:
             return None, context
 
