@@ -19,6 +19,7 @@ list is not passed in, then the first object is inspected and every trait
 from that object gets a column."""
 
 # Enthought library imports
+from __future__ import print_function
 from traits.api import Any, Bool, Callable, Dict, Function, HasTraits, \
      Int, List, Str, Trait, TraitError, Type
 
@@ -104,7 +105,7 @@ class TraitGridModel(GridModel):
 
                 # we only add traits that aren't events, since events
                 # are write-only
-                for name, trait in list(self.data[0].traits().items()):
+                for name, trait in self.data[0].traits().items():
                     if trait.type != 'event':
                         self._auto_columns.append(TraitGridColumn(name = name))
             else:
